<?php
/*
Plugin Name: Bulk Delete Spam Users
Description: A simple plugin to bulk delete spam users based on criteria like registration date or role.
Version: 1.0
Author: WPCOLLEGE
Author URI: https://wpcollege.com
*/

// Hook to add admin menu
add_action('admin_menu', 'bulk_delete_spam_users_menu');

function bulk_delete_spam_users_menu() {
    add_users_page(
        'Bulk Delete Spam Users',
        'Bulk Delete Users',
        'manage_options',
        'bulk-delete-spam-users',
        'bulk_delete_spam_users_page'
    );
}

function bulk_delete_spam_users_page() {
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions to access this page.'));
    }

    global $wpdb;

    if (isset($_POST['delete_users'])) {
        $role = sanitize_text_field($_POST['role']);
        $date = sanitize_text_field($_POST['date']);

        $query = "SELECT ID FROM {$wpdb->users} u
                  INNER JOIN {$wpdb->usermeta} um ON u.ID = um.user_id
                  WHERE um.meta_key = 'wp_capabilities' 
                  AND um.meta_value LIKE %s ";

        $params = ["%$role%"];

        if (!empty($date)) {
            $query .= " AND u.user_registered >= %s";
            $params[] = $date;
        }

        $user_ids = $wpdb->get_col($wpdb->prepare($query, $params));

        if (!empty($user_ids)) {
            foreach ($user_ids as $user_id) {
                wp_delete_user($user_id);
            }
            echo '<div class="updated"><p>' . count($user_ids) . ' users deleted successfully!</p></div>';
        } else {
            echo '<div class="error"><p>No users found matching the criteria.</p></div>';
        }
    }

    ?>
    <div class="wrap">
        <h1>Bulk Delete Spam Users</h1>
        <form method="post" action="">
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="role">User Role</label></th>
                    <td>
                        <select name="role" id="role" required>
                            <option value="subscriber">Subscriber</option>
                            <option value="customer">Customer</option>
                            <!-- Add more roles if needed -->
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="date">Registered After</label></th>
                    <td>
                        <input type="date" name="date" id="date">
                        <p class="description">Leave blank to delete all users with the selected role.</p>
                    </td>
                </tr>
            </table>
            <p class="submit">
                <input type="submit" name="delete_users" id="delete_users" class="button button-primary" value="Delete Users">
            </p>
        </form>
    </div>
    <?php
}
